==> qtsmbstatus_2.1.3.orig.tar.gz: qtsmbstatus-2.1.3/client/tr/qtsmbstatus_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name></name>
    <message>
        <source></source>
        <translatorcomment>Brazilian Portuguese translation for qtsmbstatus
Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
This file is distributed under the same license as the qtsmbstatus package.
FIRST AUTHOR &lt;EMAIL@ADDRESS&gt;, 2008.

</translatorcomment>
        <translation>Project-Id-Version: qtsmbstatus
Report-Msgid-Bugs-To: FULL NAME &lt;EMAIL@ADDRESS&gt;
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2009-10-18 03:57+0000
Last-Translator: Muriel de Souza Godoi &lt;Unknown&gt;
Language-Team: Brazilian Portuguese &lt;pt_BR@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2009-12-26 10:24+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Máquina</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Serviço</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir Arquivo</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Mostrar atividades CIFS/SMB</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimizar</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Obrigado a:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>O programa é licensiado pelos termos do GNU Licensa Pública Geral versão 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Encontrar texto</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Texto não encontrado.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Usuário %1 abriu compartilhamento %2 (%3)</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Usuário %1 abriu arquivo %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>Atividades CIFS/SMB</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Mensagem para enviar</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Mensagem para enviar para %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Você realmente quer desconectar o usuário %1?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sim</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Não</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Enviar mensagens para todos usuários</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Enviar mensagem para</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Desconectar usuário</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Uma atualização está disponível</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Uma nova versão de %1 está disponível</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Você pode fazer o download aqui: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Intervalo:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Intervalo entre requisições smbstatus em segundos, (intervalo &gt; 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Exibir compartilhamentos ocultos  (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Mostrar compartilhamentos ocultos</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notificações e log</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Log limite:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dias</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Iconizar QtSmbstatus na bandeja do sistema</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Mostrar atividades no &quot;balão de mensagens&quot;</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Estado da mensagem de notificação</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Log SMB/CIFS ativos</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Diversos</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Verificar automaticamente por atualizações</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Uma nova versão está disponível</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexão</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Nome do usuário padrão:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Conectar automaticamente ao iniciar qtsmbstatus</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Auto-conectar</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Endereço do host padrão:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Nome do usuário (padrão: nome do usuário = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Endereço do Host</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Conectar/Desconectar</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Procurar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Sobre QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Sobre QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Sobre a Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configurar clientes</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Configurar cliente QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Máquina</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Procurar máquina</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Usuário</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Procurar usuário</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>&amp;Abrir compartilhamento</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Procurar compartilhamento aberto</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Travar arquivo</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Procurar arquivo aberto</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Próximo</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Procurar texto</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Encontrar texto</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Sair do QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Mostrar atividades CIFS/SMB</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Co&amp;nectar</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Visualizar atividades</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Salvar registro</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Visualizar/esconder compartilhamento</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Visualizar/esconder arquivos</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Conectar ao servidor qtsmbstatus</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>login</source>
        <translation>conectar</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>sair</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Conecção em progresso em %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Conectado ao host</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Conexão fechada</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Login ou senha inválida!</translation>
    </message>
</context>
</TS>

==> qtsmbstatus_2.2.1.orig.tar.gz: qtsmbstatus-2.2.1/client/tr/qtsmbstatus_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name></name>
    <message>
        <source></source>
        <translatorcomment>Brazilian Portuguese translation for qtsmbstatus
Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
This file is distributed under the same license as the qtsmbstatus package.
FIRST AUTHOR &lt;EMAIL@ADDRESS&gt;, 2008.

</translatorcomment>
        <translation>Project-Id-Version: qtsmbstatus
Report-Msgid-Bugs-To: FULL NAME &lt;EMAIL@ADDRESS&gt;
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2009-10-18 03:57+0000
Last-Translator: Muriel de Souza Godoi &lt;Unknown&gt;
Language-Team: Brazilian Portuguese &lt;pt_BR@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2009-12-26 10:24+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Máquina</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Serviço</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir Arquivo</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Mostrar atividades CIFS/SMB</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimizar</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Obrigado a:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>O programa é licensiado pelos termos do GNU Licensa Pública Geral versão 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Encontrar texto</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Texto não encontrado.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Usuário %1 abriu compartilhamento %2 (%3)</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Usuário %1 abriu arquivo %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>Atividades CIFS/SMB</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Mensagem para enviar</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Mensagem para enviar para %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Você realmente quer desconectar o usuário %1?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sim</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Não</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Enviar mensagens para todos usuários</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Enviar mensagem para</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Desconectar usuário</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Uma atualização está disponível</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Uma nova versão de %1 está disponível</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Você pode fazer o download aqui: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Intervalo:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Intervalo entre requisições smbstatus em segundos, (intervalo &gt; 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Exibir compartilhamentos ocultos  (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Mostrar compartilhamentos ocultos</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notificações e log</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Log limite:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dias</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Iconizar QtSmbstatus na bandeja do sistema</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Mostrar atividades no &quot;balão de mensagens&quot;</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Estado da mensagem de notificação</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Log SMB/CIFS ativos</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Diversos</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Verificar automaticamente por atualizações</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Uma nova versão está disponível</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexão</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Nome do usuário padrão:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Conectar automaticamente ao iniciar qtsmbstatus</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Auto-conectar</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Endereço do host padrão:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Nome do usuário (padrão: nome do usuário = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Endereço do Host</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Conectar/Desconectar</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Procurar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Sobre QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Sobre QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Sobre a Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configurar clientes</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Configurar cliente QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Máquina</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Procurar máquina</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Usuário</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Procurar usuário</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>&amp;Abrir compartilhamento</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Procurar compartilhamento aberto</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Travar arquivo</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Procurar arquivo aberto</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Próximo</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Procurar texto</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Encontrar texto</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Sair do QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Mostrar atividades CIFS/SMB</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Co&amp;nectar</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Visualizar atividades</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Salvar registro</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Visualizar/esconder compartilhamento</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Visualizar/esconder arquivos</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Conectar ao servidor qtsmbstatus</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>login</source>
        <translation>conectar</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>sair</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Conecção em progresso em %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Conectado ao host</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Conexão fechada</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Login ou senha inválida!</translation>
    </message>
    <message>
        <source>The server certificate doesn&apos;t contain valid data or expired !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The authenticity of host &apos;%1&apos; can&apos;t be established.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to continue connecting ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1 Fingerprint: %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
